//
//  GLUnitConverter.h
//  Trips
//
//  Created by Jeffrey Early on 10/11/07.
//  Copyright 2007 Early Innovations, LLC. All rights reserved.
//

#import <Cocoa/Cocoa.h>

extern NSString *distanceUnitsDidChangeNotification;
extern NSString *heightUnitsDidChangeNotification;
extern NSString *speedUnitsDidChangeNotification;

extern NSString *defaultDistanceUnits;
extern NSString *defaultElevationUnits;
extern NSString *defaultSpeedUnits;


typedef enum {
	kMetricUnits,
	kUSCustomaryUnits,
} UnitsType;

typedef enum {
	kShortStyle,
	kMediumStyle,
	kLongStyle,
} DescriptionStyleType;

@interface GLUnitConverter : NSObject {

}

@property UnitsType distanceUnits;
@property UnitsType heightUnits;
@property UnitsType speedUnits;

// Returns two significant figures, with appropriate rounding.
- (NSString *) roundedDescriptionFromSeconds: (NSInteger) interval;
- (NSString *) roundedDefaultDistanceDescriptionFromMeters: (double) distance;
- (NSString *) roundedDefaultDistanceDescriptionFromMetersPerSecond: (double) speed;

// Returns a lot more sig figs.
- (NSString *) descriptionFromSeconds: (NSInteger) interval;
- (NSString *) defaultHeightDescriptionFromMeters: (double) distance;

/************************************************/
/*		Initialization							*/
/************************************************/

#pragma mark -
#pragma mark Initialization
#pragma mark

+ (id) sharedUnitConverter;

@end

/************************************************/
/*		Default Height Formatter				*/
/************************************************/

#pragma mark -
#pragma mark Default Height Formatter
#pragma mark

@interface GLDefaultHeightFormatter : NSNumberFormatter
@end

@interface GLDefaultRoundedDistanceFormatter : NSNumberFormatter
@end

@interface GLDefaultRoundedTimeFormatter : NSNumberFormatter
@end